@@ -1,3 +1,6 @@
+from httpx import AsyncClient
+from kink import di
+
 from .common.commons import Utils, RouterUtils, FileUtils, Base64Utils
 from .db.models import (
     AutoRepr, Object, BaseEntity, ModelType, CreateSchemaType, UpdateSchemaType,
@@ -20,3 +23,6 @@ __all__ = [
     "Page",
     "PageRequest"
 ]
+
+# Provision some global Dependencies
+di[AsyncClient] = lambda _di: AsyncClient(timeout=30.0)
