@@ -1,7 +1,10 @@
 import json
 
 from appodus_utils import Utils
-from appodus_utils.config.settings import appodus_base_settings
+from appodus_utils.config.settings import AppodusBaseSettings
+
+appodus_base_settings = AppodusBaseSettings()
+appodus_base_settings.set_env_vars() # Set the env vars in os.environ
 
 appodus_settings = Utils.get_from_env_fail_if_not_exists('APPODUS_SETTINGS')
 appodus_settings_dict = json.loads(appodus_settings)
