@@ -4,7 +4,7 @@ from appodus_utils import Object, BaseEntity, BaseQueryDto, PageRequest
 from sqlalchemy import Column, String, JSON, Integer
 from sqlalchemy.ext.mutable import MutableDict
 
-from main.app.integrations.ai_llm.models import MessageResponse
+from appodus_utils.integrations.ai_llm.models import MessageResponse
 
 
 class ChatHistory(BaseEntity):
