@@ -24,7 +24,7 @@ class SocialAuthProviderFactory:
             logger.debug(f"... initialized: {provider.platform} -> {provider}")
             self._factory[provider.platform] = provider
 
-    def get_auth_provider(self, provider: str) -> ISocialAuthProvider:
+    def get_auth_provider(self, provider: SocialAuthPlatform) -> ISocialAuthProvider:
         auth_provider = self._factory.get(provider)
 
         if not auth_provider:
