@@ -7,10 +7,15 @@ from pathlib import Path
 from typing import Dict, Any, Optional, List, Union
 
 from appodus_utils.exception.exceptions import ValidationException
-from pydantic import Field, field_validator, model_validator, HttpUrl, EmailStr, ConfigDict
+from pydantic import Field, field_validator, model_validator, HttpUrl, ConfigDict, field_serializer
 
 from appodus_utils import Object
 
+class PushProviderType(str, Enum):
+    FIREBASE = "firebase"
+    APNS = "apns"  # Apple Push Notification Service
+    WEB_PUSH = "web_push"
+
 class MessageChannel(str, Enum):
     SMS = "sms"
     EMAIL = "email"
@@ -189,10 +194,10 @@ class EmailRequestPayload(Object):
         default=None,
         examples=["welcome", "onboarding"]
     )
-    send_at: Optional[datetime] = Field(
-        default=None,
-        description="Schedule email for future delivery"
-    )
+    # send_at: Optional[datetime] = Field(
+    #     default=None,
+    #     description="Schedule email for future delivery"
+    # )
 
 
 class EmailPayload(EmailRequestPayload):
@@ -446,6 +451,7 @@ class PushToken(Object):
 class MessageExtras(Object):
     sandbox_mode: bool = False
     url_tags: Optional[str] = None
+    more: Optional[dict[str, Any]] = None
 
 class MessageRequestRecipient(Object):
     """
@@ -773,10 +779,13 @@ class MessageRequest(Object):
 
         return self
 
+    @field_serializer("schedule_at")
+    def serialize_schedule_at(self, value: datetime, _info):
+        if value is None:
+            return None
+        return value.isoformat()
+
     model_config = ConfigDict(
-        json_encoders = {
-            datetime: lambda v: v.isoformat()
-        },
         json_schema_extra = {
             "examples": [
                 {
