@@ -2,11 +2,11 @@ from unittest import IsolatedAsyncioTestCase
 
 import respx
 from _pytest.monkeypatch import MonkeyPatch
-from httpx import Response, Request
 from kink import di
 
 from appodus_utils import Utils
-from appodus_utils.config.settings import appodus_base_settings
+
+from appodus_utils.common.utils_settings import utils_settings
 from appodus_utils.sdk.appodus_sdk.appodus import AppodusClient
 
 class TestAppodusClient(IsolatedAsyncioTestCase):
